@@ -7,6 +7,7 @@
 #include <zypp-core/fs/PathInfo.h>
 #include <zypp-core/zyppng/core/String>
 #include <zypp-core/zyppng/base/EventDispatcher>
+#include <zypp-core/zyppng/base/Timer>
 #include <zypp-core/zyppng/base/private/linuxhelpers_p.h>
 #include <zypp-core/base/CleanerThread_p.h>
 #include <zypp-core/base/LogControl.h>
@@ -22,6 +23,11 @@
 #include <stdlib.h> // setenv
 #include <sys/prctl.h> // prctl(), PR_SET_PDEATHSIG
 
+#include <sys/syscall.h>
+#ifdef SYS_pidfd_open
+#include <poll.h>
+#endif
+
 #undef  ZYPP_BASE_LOGGER_LOGGROUP
 #define ZYPP_BASE_LOGGER_LOGGROUP "zypp::exec"
 
@@ -58,6 +64,75 @@ bool zyppng::AbstractDirectSpawnEngine::isRunning( bool wait )
   return false;
 }
 
+bool zyppng::AbstractDirectSpawnEngine::waitForExit( const std::optional<uint64_t> &timeout )
+{
+  if ( _pid < 0 ) return true;
+
+  // no timeout, wait forever
+  if ( !timeout.has_value () )
+    return !isRunning( true );
+
+  // busy loop polling in case pidfd is not available or fails, only called if we have a valid timout
+  const auto &fallbackPoll = [&]( uint64_t timeout ){
+    const auto start = Timer::now();
+    do {
+      if ( !isRunning(false) )
+        return true;
+      // give up the CPU, so we do not use 100% just to poll
+      std::this_thread::sleep_for( std::chrono::milliseconds(1) );
+    } while( Timer::elapsedSince ( start ) < timeout );
+
+    return !isRunning ( false );
+  };
+
+#ifdef SYS_pidfd_open
+    // we have pidfd support, but there is not yet a wrapper in glibc
+  const auto &zypp_pidfd_open = [](pid_t pid, unsigned int flags) -> int {
+    return syscall( SYS_pidfd_open, pid, flags );
+  };
+
+  zypp::AutoFD pidFd = zyppng::eintrSafeCall( zypp_pidfd_open, _pid, 0 );
+  if ( pidFd == -1 ) {
+    // fallback to manual polling
+    ERR << "pidfd_open failed, falling back to polling waidpid" << std::endl;
+    return fallbackPoll( *timeout );
+  }
+
+  struct pollfd pollfd;
+  pollfd.fd = pidFd;
+  pollfd.events = POLLIN;
+
+  // timeout always has a value set, we established that above
+  uint64_t tRemaining = *timeout;
+
+  const auto start = Timer::now();
+  do {
+    // posix using int as timeout, could in theory overflow so protect against it
+    int posixTimeout = tRemaining > INT_MAX ? INT_MAX : static_cast<int>(tRemaining);
+
+    int ready = poll(&pollfd, 1, posixTimeout );
+    tRemaining = *timeout - std::min<uint64_t>( Timer::elapsedSince( start ), *timeout );
+
+    if ( ready == -1 && errno != EINTR ) {
+      ERR << "Polling the pidfd failed with error: " << zypp::Errno() << std::endl;
+      if ( tRemaining > 0 ) {
+        ERR << "Falling back to manual polling for the remaining timeout." << std::endl;
+        return fallbackPoll( tRemaining );
+      }
+      break;
+    } else if ( pollfd.revents & POLLIN ) {
+      break;
+    }
+  } while( tRemaining > 0 );
+
+  // set exit status
+  return !isRunning ( false );
+#else
+  // we do not have pidfd support, need to busyloop on waitpid until timeout is over
+  return fallbackPoll( *timeout );
+#endif
+}
+
 void zyppng::AbstractDirectSpawnEngine::mapExtraFds ( int controlFd )
 {
   // we might have gotten other FDs to reuse, lets map them to STDERR_FILENO++
@@ -109,7 +184,7 @@ void zyppng::AbstractDirectSpawnEngine::mapExtraFds ( int controlFd )
   //If the rlimits are too high we need to use a different approach
   // in detecting how many fds we need to close, or otherwise we are too slow (bsc#1191324)
   if ( maxFds > 1024 && zypp::PathInfo( "/proc/self/fd" ).isExist() ) {
-    
+
     std::vector<int> fdsToClose;
     fdsToClose.reserve (256);
 
@@ -138,6 +213,24 @@ void zyppng::AbstractDirectSpawnEngine::mapExtraFds ( int controlFd )
   }
 }
 
+void zyppng::AbstractDirectSpawnEngine::resetSignals()
+{
+  // set all signal handers to their default
+  struct sigaction act;
+  memset (&act, 0, sizeof (struct sigaction));
+  act.sa_handler = SIG_DFL;
+  for ( int i = 1; i < NSIG; i++ ) {
+    // this might return -1 and set errno for unknown signals, but
+    // thats fine for us.
+    sigaction(i, &act, NULL);
+  }
+
+  // clear the sigmask
+  sigset_t     sigMask;
+  sigemptyset ( &sigMask );
+  pthread_sigmask ( SIG_SETMASK, &sigMask, nullptr );
+}
+
 bool zyppng::ForkSpawnEngine::start( const char * const *argv, int stdin_fd, int stdout_fd, int stderr_fd )
 {
   _pid = -1;
@@ -215,6 +308,7 @@ bool zyppng::ForkSpawnEngine::start( const char * const *argv, int stdin_fd, int
   {
 
     // child process
+    resetSignals();
     controlPipe->unrefRead();
 
     const auto &writeErrAndExit = [&]( int errCode, ChildErrType type ){
@@ -455,7 +549,7 @@ bool zyppng::GlibSpawnEngine::start( const char * const *argv, int stdin_fd, int
   g_autoptr(GError) error = NULL;
   g_spawn_async_with_fds(
         chdirTo,
-        (gchar **)argv,
+        const_cast<gchar**>(argv),
         envPtrs.data(),
         spawnFlags,
         needCallback ? &GlibSpawnEngine::glibSpawnCallback : nullptr,
@@ -482,14 +576,15 @@ void zyppng::GlibSpawnEngine::glibSpawnCallback(void *data)
 {
   GLibForkData *d = reinterpret_cast<GLibForkData *>(data);
 
+  d->that->resetSignals();
   bool doChroot = !d->that->_chroot.empty();
 
-  std::string execError;
-
   if ( d->that->_switchPgid )
     setpgid( 0, 0);
 
   if ( doChroot ) {
+    std::string execError;
+
     if ( ::chroot( d->that->_chroot.c_str() ) == -1 ) {
       execError = zypp::str::form( "Can't chroot to '%s' (%s).", d->that->_chroot.c_str(), strerror(errno).c_str() );
       std::cerr << execError << std::endl;// After fork log on stderr too
