@@ -249,7 +249,9 @@ void NetworkRequestDispatcherPrivate::handleMultiSocketAction(curl_socket_t nati
           request->aboutToStart( );
         }
       } else {
-        //trigger notification about file downloaded
+        // trigger notification about file downloaded
+        // we create a error from the CURL code, there might be a already cached Result which will be used instead
+        // in cases like a RangeFail where we could not recover but there also is no real error code
         NetworkRequestError e = NetworkRequestErrorPrivate::fromCurlError( *request->z_func(), res, request->errorMessage() );
         setFinished( *request->z_func(), e );
       }
@@ -308,8 +310,10 @@ void NetworkRequestDispatcherPrivate::setFinished( NetworkRequest &req, NetworkR
     rLocked = delReq( _pendingDownloads, req );
 
   void *easyHandle = req.d_func()->_easyHandle;
-  if ( easyHandle )
+  if ( easyHandle ) {
+    MIL_MEDIA << "Removing easy handle: " << easyHandle << std::endl;
     curl_multi_remove_handle( _multi, easyHandle );
+  }
 
   req.d_func()->_dispatcher = nullptr;
 
@@ -330,6 +334,7 @@ bool NetworkRequestDispatcherPrivate::addRequestToMultiHandle(NetworkRequest &re
     return false;
   }
 
+  MIL_MEDIA << "Added easy handle: " << req.d_func()->_easyHandle << std::endl;
   // make sure to wake up once to register what we have now
   _timer->start(0);
   return true;
@@ -494,6 +499,16 @@ void NetworkRequestDispatcher::cancel(NetworkRequest &req, const NetworkRequestE
   d->setFinished( req, err );
 }
 
+void NetworkRequestDispatcher::cancelAll(std::string reason)
+{
+  cancelAll( NetworkRequestErrorPrivate::customError( NetworkRequestError::Cancelled, reason.size() ? std::move(reason) : "Request explicitly cancelled" ) );
+}
+
+void NetworkRequestDispatcher::cancelAll(const NetworkRequestError &err)
+{
+  d_func()->cancelAll ( err );
+}
+
 void NetworkRequestDispatcher::run()
 {
   Z_D();
