@@ -83,6 +83,7 @@ namespace zyppng {
     if ( _easyHandle ) {
       //clean up for now, later we might reuse handles
       curl_easy_cleanup( _easyHandle );
+      MIL << _easyHandle << " curl_easy_cleanup" << std::endl;
       //reset in request but make sure the request was not enqueued again and got a new handle
       _easyHandle = nullptr;
     }
@@ -92,10 +93,11 @@ namespace zyppng {
   {
     reset();
 
-    if ( _easyHandle )
+    if ( _easyHandle ) {
       //will reset to defaults but keep live connections, session ID and DNS caches
       curl_easy_reset( _easyHandle );
-    else
+      MIL << _easyHandle << " curl_easy_reset" << std::endl;
+    } else
       _easyHandle = curl_easy_init();
     return setupHandle ( errBuf );
   }
@@ -104,6 +106,7 @@ namespace zyppng {
   {
     ::internal::setupZYPP_MEDIA_CURL_DEBUG( _easyHandle );
     curl_easy_setopt( _easyHandle, CURLOPT_ERRORBUFFER, this->_errorBuf.data() );
+    MIL << _easyHandle << " " << "URL: " << _url << std::endl;
 
     const std::string urlScheme = _url.getScheme();
     if ( urlScheme == "http" ||  urlScheme == "https" )
@@ -272,7 +275,7 @@ namespace zyppng {
         }
         else
         {
-          DBG << _easyHandle << " "  << _easyHandle << " "  << "Proxy: using provided proxy-user '" << _settings.proxyUsername() << "'" << std::endl;
+          DBG << _easyHandle << " " << "Proxy: using provided proxy-user '" << _settings.proxyUsername() << "'" << std::endl;
         }
 
         if ( ! proxyuserpwd.empty() )
@@ -305,12 +308,12 @@ namespace zyppng {
         setCurlOption(CURLOPT_MAX_RECV_SPEED_LARGE, locSet.maxDownloadSpeed());
 #endif
 
-      zypp::filesystem::assert_file_mode( _currentCookieFile, 0600 );
-      if ( locSet.cookieFileEnabled() )
+      if ( locSet.cookieFileEnabled() ) {
+        DBG << _easyHandle << " " << "Cookie file enabled: " << _currentCookieFile << std::endl;
+        zypp::filesystem::assert_file_mode( _currentCookieFile, 0600 );
         setCurlOption( CURLOPT_COOKIEFILE, _currentCookieFile.c_str() );
-      else
-        MIL << _easyHandle << " " << "No cookies requested" << std::endl;
-      setCurlOption(CURLOPT_COOKIEJAR, _currentCookieFile.c_str() );
+        setCurlOption(CURLOPT_COOKIEJAR, _currentCookieFile.c_str() );
+      }
 
 #if CURLVERSION_AT_LEAST(7,18,0)
       // bnc #306272
@@ -436,6 +439,7 @@ namespace zyppng {
         //
         // Note: Even creating a new handle will NOT fix the issue
         curl_easy_reset( _easyHandle );
+        MIL << _easyHandle << " curl_easy_reset after hadRangeFail" << std::endl;
       }
       if ( !setupHandle(errBuf))
         return false;
@@ -586,7 +590,6 @@ namespace zyppng {
       DBG << that->_easyHandle << " " << "Curl progress callback was called in invalid state "<< that->z_func()->state() << std::endl;
       return -1;
     }
-
     auto &rmode = std::get<running_t>( that->_runningMode );
 
     //reset the timer
@@ -621,6 +624,10 @@ namespace zyppng {
       else
         hdr = std::string_view();
 
+      if ( !std::holds_alternative<running_t>(_runningMode) ){
+        DBG << _easyHandle << " " << "Curl headerfunction callback was called in invalid state "<< z_func()->state() << std::endl;
+        return -1;
+      }
       auto &rmode = std::get<running_t>( _runningMode );
       if ( !hdr.size() ) {
         return ( bytes );
@@ -661,17 +668,21 @@ namespace zyppng {
 
   size_t NetworkRequestPrivate::writefunction( char *data, std::optional<off_t> offset, size_t max )
   {
-    resetActivityTimer();
-
     //it is valid to call this function with no data to write, just return OK
     if ( max == 0)
       return 0;
 
+    resetActivityTimer();
+
     //in case of a HEAD request, we do not write anything
     if ( _options & NetworkRequest::HeadRequest ) {
       return ( max );
     }
 
+    if ( !std::holds_alternative<running_t>(_runningMode) ){
+      DBG << _easyHandle << " " << "Curl writefunction callback was called in invalid state "<< z_func()->state() << std::endl;
+      return -1;
+    }
     auto &rmode = std::get<running_t>( _runningMode );
 
     // if we have no open file create or open it
