@@ -23,32 +23,36 @@ namespace zypp
   namespace media
   {
 
-    /**
-     * Holds transfer setting
-     */
+    ///////////////////////////////////////////////////////////////////
+    /// \brief Holds transfer setting
+    ///
+    /// \note bsc#1212187: HTTP/2 RFC 9113 forbids fields ending with a
+    /// space. The class asserts \ref headers and \ref userAgentString
+    /// return trimmed strings. Strings are trimmed when set. Empty
+    //  strings are discarded.
     class TransferSettings
     {
     public:
       /** Constructs a transfer program cmd line access. */
       TransferSettings();
 
-      typedef std::vector<std::string> Headers;
+      using Headers = std::vector<std::string>;
 
       /** reset the settings to the defaults */
       void reset();
 
-      /** add a header, on the form "Foo: Bar" */
+      /** add a header, on the form "Foo: Bar" (trims)*/
       void addHeader( std::string && val_r );
       void addHeader( const std::string & val_r );
 
-      /** returns a list of all added headers */
+      /** returns a list of all added headers (trimmed) */
       const Headers &headers() const;
 
-      /** sets the user agent ie: "Mozilla v3" */
+      /** sets the user agent ie: "Mozilla v3" (trims) */
       void setUserAgentString( std::string && val_r );
-      void setUserAgentString( const std::string && val_r );
+      void setUserAgentString( const std::string &val_r );
 
-      /** user agent string */
+      /** user agent string (trimmed)*/
       const std::string &userAgentString() const;
 
 
@@ -200,6 +204,10 @@ namespace zypp
       /** SSL client key file */
       const Pathname &clientKeyPath() const;
 
+      /** Enable or disable the use of the cookie file */
+      void setEnableCookieFile( bool enable = true );
+      bool cookieFileEnabled() const;
+
     protected:
       class Impl;
       RWCOW_pointer<Impl> _impl;
