@@ -47,14 +47,14 @@ namespace zypp
     bool isDependencyAttribute( const sat::SolvAttr& attr_r )
     {
       static sat::SolvAttr deps[] = {
-        SolvAttr::provides,
-        SolvAttr::requires,
-        SolvAttr::recommends,
-        SolvAttr::obsoletes,
-        SolvAttr::conflicts,
-        SolvAttr::suggests,
-        SolvAttr::supplements,
-        SolvAttr::enhances,
+        SolvAttr::dep_provides,
+        SolvAttr::dep_requires,
+        SolvAttr::dep_recommends,
+        SolvAttr::dep_obsoletes,
+        SolvAttr::dep_conflicts,
+        SolvAttr::dep_suggests,
+        SolvAttr::dep_supplements,
+        SolvAttr::dep_enhances,
       };
       for_( it, arrayBegin(deps), arrayEnd(deps) )
         if ( *it == attr_r )
@@ -878,10 +878,6 @@ namespace zypp
 
   void PoolQuery::setComment(const std::string & comment) const
   { _pimpl->_comment = comment; }
-#if LEGACY(1722)
-  void PoolQuery::setComment(const std::string & comment)
-  { _pimpl->_comment = comment; }
-#endif
 
   void PoolQuery::addString(const std::string & value)
   { _pimpl->_strings.insert(value); }
